@@ -5,7 +5,7 @@ use std::mem;
 /// Closest points information.
 #[derive(Debug, PartialEq, Clone, Copy)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
-pub enum ClosestPoints<N: RealField> {
+pub enum ClosestPoints<N: RealField + Copy> {
     /// The two objects are intersecting.
     Intersecting,
     /// The two objects are non-intersecting but closer than a given user-defined distance.
@@ -14,7 +14,7 @@ pub enum ClosestPoints<N: RealField> {
     Disjoint,
 }
 
-impl<N: RealField> ClosestPoints<N> {
+impl<N: RealField + Copy> ClosestPoints<N> {
     /// Swaps the two points.
     pub fn flip(&mut self) {
         if let ClosestPoints::WithinMargin(ref mut p1, ref mut p2) = *self {
