@@ -8,7 +8,7 @@ use std::f64;
 /// Shape of a box.
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[derive(PartialEq, Debug, Copy, Clone)]
-pub struct Cuboid<N: RealField> {
+pub struct Cuboid<N: RealField + Copy> {
     /// The half-extents of the cuboid.
     pub half_extents: Vector<N>,
 }
@@ -20,7 +20,7 @@ pub struct Cuboid<N: RealField> {
 //                      the part `id >> 2` follow the same rule as the vertex id.
 // FeatureId::Face(id): if `id` lies in [0,1] (or [0 2] in 3D) indicates the axis (x, y, z) corresponding to the face normal.
 //                      If `id` is greater than 1 (or 2 in 3D), then the negative axis (-x, -y, -z) is given by `id - 2` (or `id - 3` in 3D).
-impl<N: RealField> Cuboid<N> {
+impl<N: RealField + Copy> Cuboid<N> {
     /// Creates a new box from its half-extents. Half-extents are the box half-width along each
     /// axis. Each half-extent must be positive.
     #[inline]
@@ -29,7 +29,7 @@ impl<N: RealField> Cuboid<N> {
     }
 }
 
-impl<N: RealField> Cuboid<N> {
+impl<N: RealField + Copy> Cuboid<N> {
     /// The half-extents of this box. Half-extents are the box half-width along each axis.
     #[inline]
     #[deprecated(note = "use the `self.half_extents` public field directly.")]
@@ -132,7 +132,7 @@ impl<N: RealField> Cuboid<N> {
     }
 }
 
-impl<N: RealField> SupportMap<N> for Cuboid<N> {
+impl<N: RealField + Copy> SupportMap<N> for Cuboid<N> {
     #[inline]
     fn local_support_point(&self, dir: &Vector<N>) -> Point<N> {
         let mut res = self.half_extents;
@@ -145,7 +145,7 @@ impl<N: RealField> SupportMap<N> for Cuboid<N> {
     }
 }
 
-impl<N: RealField> ConvexPolyhedron<N> for Cuboid<N> {
+impl<N: RealField + Copy> ConvexPolyhedron<N> for Cuboid<N> {
     fn vertex(&self, id: FeatureId) -> Point<N> {
         let vid = id.unwrap_vertex();
         let mut res = self.half_extents;
