@@ -3,7 +3,7 @@ use na::RealField;
 use crate::procedural::TriMesh;
 
 /// Trait implemented by shapes that can be approximated by a triangle mesh.
-pub trait ToTriMesh<N: RealField> {
+pub trait ToTriMesh<N: RealField + Copy> {
     type DiscretizationParameter;
 
     /// Builds a triangle mesh from this shape.
