@@ -2,7 +2,7 @@ use na::{Point2, RealField};
 
 // FIXME: move this on ncollide_geometry.
 /// Tests if the given point is inside of a polygon with arbitrary orientation.
-pub fn point_in_poly2d<N: RealField>(pt: &Point2<N>, poly: &[Point2<N>]) -> bool {
+pub fn point_in_poly2d<N: RealField + Copy>(pt: &Point2<N>, poly: &[Point2<N>]) -> bool {
     if poly.len() == 0 {
         false
     } else {
